(apply-values m f & ks)http://blog.jayfields.com/2011/01/clojure-select-keys-select-values-and.html
(contains-any? m xs)Returns true if map m contains any key defined in sequence xs
Returns true if map m contains any key defined in sequence xs
(deep-contains? m k)Version of clojure.core/contains? that works with nested maps
Version of clojure.core/contains? that works with nested maps
(find-any m xs)Returns first key found in map m supplied by sequence of keys xs
Returns first key found in map m supplied by sequence of keys xs
(find-nested m k)(nest & forms)Nesting macro, puts every form as the last of the previous one.
This has the effect of flattening if, when, let, etc. by putting the else (for if) or the last (and often single) expression of the body (for when, let, loop etc.) out and after the form.
This keeps the main code path vertical, while special cases branch out of the main path.
Nesting macro, puts every form as the last of the previous one. This has the effect of flattening if, when, let, etc. by putting the else (for if) or the last (and often single) expression of the body (for when, let, loop etc.) out and after the form. This keeps the main code path vertical, while special cases branch out of the main path.
(seek pred coll)(seek pred coll not-found)Returns first item from coll for which (pred item) returns true. Returns nil if no such item is present, or the not-found value if supplied.
Usage: (seek even? [1 2 3 4]) => 2
Returns first item from coll for which (pred item) returns true. Returns nil if no such item is present, or the not-found value if supplied. Usage: (seek even? [1 2 3 4]) => 2
(select-paths m paths)(select-values m ks)http://blog.jayfields.com/2011/01/clojure-select-keys-select-values-and.html
(slice n coll)Divide coll into n approximately equal slices.
Divide coll into n approximately equal slices.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |